YARP 2.3.15 (2012-01-27)                                              {#v2_3_15}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.14...v2.3.15`):

```
    14	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     9	Lorenzo Natale <lorenzo.natale@iit.it>
     8	Ali Paikan <ali.paikan@iit.it>
     4	Andrea Del Prete <andrea.delprete@iit.it>
     1	Alberto Cardellino <alberto.cardellino@iit.it>
     1	Ze Ji <z.ji@herts.ac.uk>
```
